.. image:: ../../_static/CSAwesomeLogo.png
    :width: 350
    :align: center


Meet The Interviewees
:::::::::::::::::::::::::::::::::::::

.. toctree::
   :maxdepth: 3

   Interviewees/A_Taylor.rst
   Interviewees/B_Hickerson.rst
   Interviewees/B_Mariscal.rst
   Interviewees/C_De_Lira.rst
   Interviewees/C_Mbayo.rst
   Interviewees/D_Deinde-Smith.rst
   Interviewees/E_Espinoza.rst
   Interviewees/G_Opoku-Boateng.rst
   Interviewees/J_Gilbert.rst
   Interviewees/L_Morales.rst
   Interviewees/L_Vocos.rst
   Interviewees/L_Diaz.rst
   Interviewees/M_Rodriguez.rst
   Interviewees/N_Gaskins.rst
..  These do not exist yet
   Interviewees/O_Romero.rst
   Interviewees/R_Garcia.rst
   Interviewees/R_Tillman-French.rst
   Interviewees/S_Seibel.rst
   Interviewees/S_Vivas.rst
   Interviewees/T_Pope.rst
   Interviewees/W_Sheppard.rst
   Interviewees/Y_Salazar.rst